/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2016 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension.data;

import org.fortiss.tooling.kernel.extension.ITutorialStepCompletionChecker;
import org.fortiss.tooling.kernel.extension.ITutorialWhitelistProvider;
import org.fortiss.tooling.kernel.extension.base.TutorialBlacklistAllProvider;

/**
 * Data class for steps of tutorials.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating RED Hash:
 */
public abstract class TutorialStep {
	/** The title of the tutorial. */
	private final String title;

	/** Constructor. */
	public TutorialStep(String title) {
		this.title = title;
	}

	/** Returns the title of this tutorial step. */
	public final String getTitle() {
		return title;
	}

	/**
	 * Returns the step-specific whitelist provider. The default returns a provider blacklisting
	 * everything.
	 */
	public ITutorialWhitelistProvider getWhitelistProvider() {
		return new TutorialBlacklistAllProvider();
	}

	/**
	 * Returns the completion checker for this tutorial step. Sub-classes MUST NOT return
	 * <code>null</code>.
	 */
	public abstract ITutorialStepCompletionChecker getCompletionChecker();
}
